Class: Aws::Inspector::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Inspector::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-inspector/client.rb,
sig/client.rbs
Overview
An API client for Inspector. To construct a client, you need to configure a :region and :credentials.
client = Aws::Inspector::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddAttributesToFindingsResponseSuccess, _CreateAssessmentTargetResponseSuccess, _CreateAssessmentTemplateResponseSuccess, _CreateExclusionsPreviewResponseSuccess, _CreateResourceGroupResponseSuccess, _DescribeAssessmentRunsResponseSuccess, _DescribeAssessmentTargetsResponseSuccess, _DescribeAssessmentTemplatesResponseSuccess, _DescribeCrossAccountAccessRoleResponseSuccess, _DescribeExclusionsResponseSuccess, _DescribeFindingsResponseSuccess, _DescribeResourceGroupsResponseSuccess, _DescribeRulesPackagesResponseSuccess, _GetAssessmentReportResponseSuccess, _GetExclusionsPreviewResponseSuccess, _GetTelemetryMetadataResponseSuccess, _ListAssessmentRunAgentsResponseSuccess, _ListAssessmentRunsResponseSuccess, _ListAssessmentTargetsResponseSuccess, _ListAssessmentTemplatesResponseSuccess, _ListEventSubscriptionsResponseSuccess, _ListExclusionsResponseSuccess, _ListFindingsResponseSuccess, _ListRulesPackagesResponseSuccess, _ListTagsForResourceResponseSuccess, _PreviewAgentsResponseSuccess, _RemoveAttributesFromFindingsResponseSuccess, _StartAssessmentRunResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
-
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup.
-
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.
-
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template.
-
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target.
-
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
-
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
-
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
-
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
-
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
-
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
-
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
-
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions' ARNs.
-
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
-
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
-
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
-
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
-
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token.
-
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
-
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
-
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account.
-
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
-
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.
-
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
-
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
-
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
-
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
-
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
-
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template.
-
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
-
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-inspector/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3162 3163 3164 |
# File 'lib/aws-sdk-inspector/client.rb', line 3162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3165 3166 3167 |
# File 'lib/aws-sdk-inspector/client.rb', line 3165 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
87 |
# File 'sig/client.rbs', line 87
def add_attributes_to_findings: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 |
# File 'lib/aws-sdk-inspector/client.rb', line 3135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Inspector') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-inspector' context[:gem_version] = '1.93.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target. If the service-linked role isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments. You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account. For more information, see Amazon Inspector Assessment Targets.
103 |
# File 'sig/client.rbs', line 103
def create_assessment_target: (
|
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target. If the service-linked role isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments.
114 |
# File 'sig/client.rbs', line 114
def create_assessment_template: (
|
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template. The exclusions preview lists the potential exclusions (ExclusionPreview) that Inspector can detect before it runs the assessment.
133 |
# File 'sig/client.rbs', line 133
def create_exclusions_preview: (
|
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target. For more information, see CreateAssessmentTarget.
143 |
# File 'sig/client.rbs', line 143
def create_resource_group: (
|
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
154 |
# File 'sig/client.rbs', line 154
def delete_assessment_run: (
|
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
160 |
# File 'sig/client.rbs', line 160
def delete_assessment_target: (
|
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
166 |
# File 'sig/client.rbs', line 166
def delete_assessment_template: (
|
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
177 |
# File 'sig/client.rbs', line 177
def describe_assessment_runs: (
|
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
188 |
# File 'sig/client.rbs', line 188
def describe_assessment_targets: (
|
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
199 |
# File 'sig/client.rbs', line 199
def describe_assessment_templates: (
|
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
211 212 |
# File 'sig/client.rbs', line 211
def describe_cross_account_access_role: () -> _DescribeCrossAccountAccessRoleResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _DescribeCrossAccountAccessRoleResponseSuccess
|
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions' ARNs.
220 |
# File 'sig/client.rbs', line 220
def describe_exclusions: (
|
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
232 |
# File 'sig/client.rbs', line 232
def describe_findings: (
|
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
244 |
# File 'sig/client.rbs', line 244
def describe_resource_groups: (
|
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
255 |
# File 'sig/client.rbs', line 255
def describe_rules_packages: (
|
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
267 |
# File 'sig/client.rbs', line 267
def get_assessment_report: (
|
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token. You can obtain the preview token by running the CreateExclusionsPreview API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
281 |
# File 'sig/client.rbs', line 281
def get_exclusions_preview: (
|
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
295 |
# File 'sig/client.rbs', line 295
def get_telemetry_metadata: (
|
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
306 |
# File 'sig/client.rbs', line 306
def list_assessment_run_agents: (
|
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
323 |
# File 'sig/client.rbs', line 323
def list_assessment_runs: (
|
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account. For more information about assessment targets, see Amazon Inspector Assessment Targets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
357 |
# File 'sig/client.rbs', line 357
def list_assessment_targets: (
|
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
372 |
# File 'sig/client.rbs', line 372
def list_assessment_templates: (
|
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template. For more information, see SubscribeToEvent and UnsubscribeFromEvent.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
393 |
# File 'sig/client.rbs', line 393
def list_event_subscriptions: (
|
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
406 |
# File 'sig/client.rbs', line 406
def list_exclusions: (
|
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
419 |
# File 'sig/client.rbs', line 419
def list_findings: (
|
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
455 |
# File 'sig/client.rbs', line 455
def list_rules_packages: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
466 |
# File 'sig/client.rbs', line 466
def list_tags_for_resource: (
|
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
477 |
# File 'sig/client.rbs', line 477
def preview_agents: (
|
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
485 |
# File 'sig/client.rbs', line 485
def register_cross_account_access_role: (
|
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
495 |
# File 'sig/client.rbs', line 495
def remove_attributes_from_findings: (
|
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
502 |
# File 'sig/client.rbs', line 502
def set_tags_for_resource: (
|
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.
518 |
# File 'sig/client.rbs', line 518
def start_assessment_run: (
|
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
525 |
# File 'sig/client.rbs', line 525
def stop_assessment_run: (
|
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
532 |
# File 'sig/client.rbs', line 532
def subscribe_to_event: (
|
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
540 |
# File 'sig/client.rbs', line 540
def unsubscribe_from_event: (
|
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target.
548 |
# File 'sig/client.rbs', line 548
def update_assessment_target: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3155 3156 3157 |
# File 'lib/aws-sdk-inspector/client.rb', line 3155 def waiter_names [] end |