Class: Aws::Inspector::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Inspector::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-inspector/client.rb
Overview
An API client for Inspector. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Inspector::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
-
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup.
-
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.
-
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template.
-
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target.
-
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
-
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
-
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
-
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
-
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
-
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
-
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
-
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions’ ARNs.
-
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
-
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
-
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
-
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
-
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token.
-
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
-
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
-
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account.
-
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
-
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.
-
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
-
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
-
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
-
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
-
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
-
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template.
-
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
-
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-inspector/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3162 3163 3164 |
# File 'lib/aws-sdk-inspector/client.rb', line 3162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3165 3166 3167 |
# File 'lib/aws-sdk-inspector/client.rb', line 3165 def errors_module Errors end |
Instance Method Details
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
543 544 545 546 |
# File 'lib/aws-sdk-inspector/client.rb', line 543 def add_attributes_to_findings(params = {}, = {}) req = build_request(:add_attributes_to_findings, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 |
# File 'lib/aws-sdk-inspector/client.rb', line 3135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Inspector') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-inspector' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target. If the [service-linked role] isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments. You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account. For more information, see [ Amazon Inspector Assessment Targets].
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html [2]: docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html
609 610 611 612 |
# File 'lib/aws-sdk-inspector/client.rb', line 609 def create_assessment_target(params = {}, = {}) req = build_request(:create_assessment_target, params) req.send_request() end |
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target. If the [service-linked role] isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments.
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html
699 700 701 702 |
# File 'lib/aws-sdk-inspector/client.rb', line 699 def create_assessment_template(params = {}, = {}) req = build_request(:create_assessment_template, params) req.send_request() end |
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template. The exclusions preview lists the potential exclusions (ExclusionPreview) that Inspector can detect before it runs the assessment.
731 732 733 734 |
# File 'lib/aws-sdk-inspector/client.rb', line 731 def create_exclusions_preview(params = {}, = {}) req = build_request(:create_exclusions_preview, params) req.send_request() end |
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target. For more information, see CreateAssessmentTarget.
793 794 795 796 |
# File 'lib/aws-sdk-inspector/client.rb', line 793 def create_resource_group(params = {}, = {}) req = build_request(:create_resource_group, params) req.send_request() end |
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
825 826 827 828 |
# File 'lib/aws-sdk-inspector/client.rb', line 825 def delete_assessment_run(params = {}, = {}) req = build_request(:delete_assessment_run, params) req.send_request() end |
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
857 858 859 860 |
# File 'lib/aws-sdk-inspector/client.rb', line 857 def delete_assessment_target(params = {}, = {}) req = build_request(:delete_assessment_target, params) req.send_request() end |
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
890 891 892 893 |
# File 'lib/aws-sdk-inspector/client.rb', line 890 def delete_assessment_template(params = {}, = {}) req = build_request(:delete_assessment_template, params) req.send_request() end |
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
1029 1030 1031 1032 |
# File 'lib/aws-sdk-inspector/client.rb', line 1029 def describe_assessment_runs(params = {}, = {}) req = build_request(:describe_assessment_runs, params) req.send_request() end |
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
1094 1095 1096 1097 |
# File 'lib/aws-sdk-inspector/client.rb', line 1094 def describe_assessment_targets(params = {}, = {}) req = build_request(:describe_assessment_targets, params) req.send_request() end |
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
1170 1171 1172 1173 |
# File 'lib/aws-sdk-inspector/client.rb', line 1170 def describe_assessment_templates(params = {}, = {}) req = build_request(:describe_assessment_templates, params) req.send_request() end |
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
1209 1210 1211 1212 |
# File 'lib/aws-sdk-inspector/client.rb', line 1209 def describe_cross_account_access_role(params = {}, = {}) req = build_request(:describe_cross_account_access_role, params) req.send_request() end |
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions’ ARNs.
1257 1258 1259 1260 |
# File 'lib/aws-sdk-inspector/client.rb', line 1257 def describe_exclusions(params = {}, = {}) req = build_request(:describe_exclusions, params) req.send_request() end |
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
1391 1392 1393 1394 |
# File 'lib/aws-sdk-inspector/client.rb', line 1391 def describe_findings(params = {}, = {}) req = build_request(:describe_findings, params) req.send_request() end |
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
1458 1459 1460 1461 |
# File 'lib/aws-sdk-inspector/client.rb', line 1458 def describe_resource_groups(params = {}, = {}) req = build_request(:describe_resource_groups, params) req.send_request() end |
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
1527 1528 1529 1530 |
# File 'lib/aws-sdk-inspector/client.rb', line 1527 def describe_rules_packages(params = {}, = {}) req = build_request(:describe_rules_packages, params) req.send_request() end |
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
1574 1575 1576 1577 |
# File 'lib/aws-sdk-inspector/client.rb', line 1574 def get_assessment_report(params = {}, = {}) req = build_request(:get_assessment_report, params) req.send_request() end |
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token. You can obtain the preview token by running the CreateExclusionsPreview API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-inspector/client.rb', line 1643 def get_exclusions_preview(params = {}, = {}) req = build_request(:get_exclusions_preview, params) req.send_request() end |
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
1836 1837 1838 1839 |
# File 'lib/aws-sdk-inspector/client.rb', line 1836 def (params = {}, = {}) req = build_request(:get_telemetry_metadata, params) req.send_request() end |
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2076 2077 2078 2079 |
# File 'lib/aws-sdk-inspector/client.rb', line 2076 def list_assessment_run_agents(params = {}, = {}) req = build_request(:list_assessment_run_agents, params) req.send_request() end |
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2176 2177 2178 2179 |
# File 'lib/aws-sdk-inspector/client.rb', line 2176 def list_assessment_runs(params = {}, = {}) req = build_request(:list_assessment_runs, params) req.send_request() end |
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account. For more information about assessment targets, see [Amazon Inspector Assessment Targets].
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2253 2254 2255 2256 |
# File 'lib/aws-sdk-inspector/client.rb', line 2253 def list_assessment_targets(params = {}, = {}) req = build_request(:list_assessment_targets, params) req.send_request() end |
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2340 2341 2342 2343 |
# File 'lib/aws-sdk-inspector/client.rb', line 2340 def list_assessment_templates(params = {}, = {}) req = build_request(:list_assessment_templates, params) req.send_request() end |
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template. For more information, see SubscribeToEvent and UnsubscribeFromEvent.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2421 2422 2423 2424 |
# File 'lib/aws-sdk-inspector/client.rb', line 2421 def list_event_subscriptions(params = {}, = {}) req = build_request(:list_event_subscriptions, params) req.send_request() end |
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2469 2470 2471 2472 |
# File 'lib/aws-sdk-inspector/client.rb', line 2469 def list_exclusions(params = {}, = {}) req = build_request(:list_exclusions, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2570 2571 2572 2573 |
# File 'lib/aws-sdk-inspector/client.rb', line 2570 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2633 2634 2635 2636 |
# File 'lib/aws-sdk-inspector/client.rb', line 2633 def list_rules_packages(params = {}, = {}) req = build_request(:list_rules_packages, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
2683 2684 2685 2686 |
# File 'lib/aws-sdk-inspector/client.rb', line 2683 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2758 2759 2760 2761 |
# File 'lib/aws-sdk-inspector/client.rb', line 2758 def preview_agents(params = {}, = {}) req = build_request(:preview_agents, params) req.send_request() end |
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
2792 2793 2794 2795 |
# File 'lib/aws-sdk-inspector/client.rb', line 2792 def register_cross_account_access_role(params = {}, = {}) req = build_request(:register_cross_account_access_role, params) req.send_request() end |
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
2851 2852 2853 2854 |
# File 'lib/aws-sdk-inspector/client.rb', line 2851 def remove_attributes_from_findings(params = {}, = {}) req = build_request(:remove_attributes_from_findings, params) req.send_request() end |
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
2899 2900 2901 2902 |
# File 'lib/aws-sdk-inspector/client.rb', line 2899 def (params = {}, = {}) req = build_request(:set_tags_for_resource, params) req.send_request() end |
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.
2952 2953 2954 2955 |
# File 'lib/aws-sdk-inspector/client.rb', line 2952 def start_assessment_run(params = {}, = {}) req = build_request(:start_assessment_run, params) req.send_request() end |
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
2992 2993 2994 2995 |
# File 'lib/aws-sdk-inspector/client.rb', line 2992 def stop_assessment_run(params = {}, = {}) req = build_request(:stop_assessment_run, params) req.send_request() end |
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
3036 3037 3038 3039 |
# File 'lib/aws-sdk-inspector/client.rb', line 3036 def subscribe_to_event(params = {}, = {}) req = build_request(:subscribe_to_event, params) req.send_request() end |
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
3080 3081 3082 3083 |
# File 'lib/aws-sdk-inspector/client.rb', line 3080 def unsubscribe_from_event(params = {}, = {}) req = build_request(:unsubscribe_from_event, params) req.send_request() end |
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target.
3126 3127 3128 3129 |
# File 'lib/aws-sdk-inspector/client.rb', line 3126 def update_assessment_target(params = {}, = {}) req = build_request(:update_assessment_target, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3155 3156 3157 |
# File 'lib/aws-sdk-inspector/client.rb', line 3155 def waiter_names [] end |