Class: Aws::Inspector::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Inspector::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-inspector/client.rb
Overview
An API client for Inspector. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Inspector::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
-
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup.
-
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.
-
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template.
-
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target.
-
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
-
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
-
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
-
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
-
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
-
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
-
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
-
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions’ ARNs.
-
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
-
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
-
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
-
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
-
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token.
-
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
-
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
-
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account.
-
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
-
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.
-
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
-
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
-
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
-
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
-
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
-
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
-
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template.
-
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
-
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
-
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
423 424 425 |
# File 'lib/aws-sdk-inspector/client.rb', line 423 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3102 3103 3104 |
# File 'lib/aws-sdk-inspector/client.rb', line 3102 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3105 3106 3107 |
# File 'lib/aws-sdk-inspector/client.rb', line 3105 def errors_module Errors end |
Instance Method Details
#add_attributes_to_findings(params = {}) ⇒ Types::AddAttributesToFindingsResponse
Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.
488 489 490 491 |
# File 'lib/aws-sdk-inspector/client.rb', line 488 def add_attributes_to_findings(params = {}, = {}) req = build_request(:add_attributes_to_findings, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 |
# File 'lib/aws-sdk-inspector/client.rb', line 3080 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-inspector' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assessment_target(params = {}) ⇒ Types::CreateAssessmentTargetResponse
Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target. If the [service-linked role] isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments. You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account. For more information, see [ Amazon Inspector Assessment Targets].
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html [2]: docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html
554 555 556 557 |
# File 'lib/aws-sdk-inspector/client.rb', line 554 def create_assessment_target(params = {}, = {}) req = build_request(:create_assessment_target, params) req.send_request() end |
#create_assessment_template(params = {}) ⇒ Types::CreateAssessmentTemplateResponse
Creates an assessment template for the assessment target that is specified by the ARN of the assessment target. If the [service-linked role] isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments.
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html
644 645 646 647 |
# File 'lib/aws-sdk-inspector/client.rb', line 644 def create_assessment_template(params = {}, = {}) req = build_request(:create_assessment_template, params) req.send_request() end |
#create_exclusions_preview(params = {}) ⇒ Types::CreateExclusionsPreviewResponse
Starts the generation of an exclusions preview for the specified assessment template. The exclusions preview lists the potential exclusions (ExclusionPreview) that Inspector can detect before it runs the assessment.
676 677 678 679 |
# File 'lib/aws-sdk-inspector/client.rb', line 676 def create_exclusions_preview(params = {}, = {}) req = build_request(:create_exclusions_preview, params) req.send_request() end |
#create_resource_group(params = {}) ⇒ Types::CreateResourceGroupResponse
Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target. For more information, see CreateAssessmentTarget.
738 739 740 741 |
# File 'lib/aws-sdk-inspector/client.rb', line 738 def create_resource_group(params = {}, = {}) req = build_request(:create_resource_group, params) req.send_request() end |
#delete_assessment_run(params = {}) ⇒ Struct
Deletes the assessment run that is specified by the ARN of the assessment run.
770 771 772 773 |
# File 'lib/aws-sdk-inspector/client.rb', line 770 def delete_assessment_run(params = {}, = {}) req = build_request(:delete_assessment_run, params) req.send_request() end |
#delete_assessment_target(params = {}) ⇒ Struct
Deletes the assessment target that is specified by the ARN of the assessment target.
802 803 804 805 |
# File 'lib/aws-sdk-inspector/client.rb', line 802 def delete_assessment_target(params = {}, = {}) req = build_request(:delete_assessment_target, params) req.send_request() end |
#delete_assessment_template(params = {}) ⇒ Struct
Deletes the assessment template that is specified by the ARN of the assessment template.
835 836 837 838 |
# File 'lib/aws-sdk-inspector/client.rb', line 835 def delete_assessment_template(params = {}, = {}) req = build_request(:delete_assessment_template, params) req.send_request() end |
#describe_assessment_runs(params = {}) ⇒ Types::DescribeAssessmentRunsResponse
Describes the assessment runs that are specified by the ARNs of the assessment runs.
974 975 976 977 |
# File 'lib/aws-sdk-inspector/client.rb', line 974 def describe_assessment_runs(params = {}, = {}) req = build_request(:describe_assessment_runs, params) req.send_request() end |
#describe_assessment_targets(params = {}) ⇒ Types::DescribeAssessmentTargetsResponse
Describes the assessment targets that are specified by the ARNs of the assessment targets.
1039 1040 1041 1042 |
# File 'lib/aws-sdk-inspector/client.rb', line 1039 def describe_assessment_targets(params = {}, = {}) req = build_request(:describe_assessment_targets, params) req.send_request() end |
#describe_assessment_templates(params = {}) ⇒ Types::DescribeAssessmentTemplatesResponse
Describes the assessment templates that are specified by the ARNs of the assessment templates.
1115 1116 1117 1118 |
# File 'lib/aws-sdk-inspector/client.rb', line 1115 def describe_assessment_templates(params = {}, = {}) req = build_request(:describe_assessment_templates, params) req.send_request() end |
#describe_cross_account_access_role(params = {}) ⇒ Types::DescribeCrossAccountAccessRoleResponse
Describes the IAM role that enables Amazon Inspector to access your AWS account.
1154 1155 1156 1157 |
# File 'lib/aws-sdk-inspector/client.rb', line 1154 def describe_cross_account_access_role(params = {}, = {}) req = build_request(:describe_cross_account_access_role, params) req.send_request() end |
#describe_exclusions(params = {}) ⇒ Types::DescribeExclusionsResponse
Describes the exclusions that are specified by the exclusions’ ARNs.
1202 1203 1204 1205 |
# File 'lib/aws-sdk-inspector/client.rb', line 1202 def describe_exclusions(params = {}, = {}) req = build_request(:describe_exclusions, params) req.send_request() end |
#describe_findings(params = {}) ⇒ Types::DescribeFindingsResponse
Describes the findings that are specified by the ARNs of the findings.
1336 1337 1338 1339 |
# File 'lib/aws-sdk-inspector/client.rb', line 1336 def describe_findings(params = {}, = {}) req = build_request(:describe_findings, params) req.send_request() end |
#describe_resource_groups(params = {}) ⇒ Types::DescribeResourceGroupsResponse
Describes the resource groups that are specified by the ARNs of the resource groups.
1403 1404 1405 1406 |
# File 'lib/aws-sdk-inspector/client.rb', line 1403 def describe_resource_groups(params = {}, = {}) req = build_request(:describe_resource_groups, params) req.send_request() end |
#describe_rules_packages(params = {}) ⇒ Types::DescribeRulesPackagesResponse
Describes the rules packages that are specified by the ARNs of the rules packages.
1472 1473 1474 1475 |
# File 'lib/aws-sdk-inspector/client.rb', line 1472 def describe_rules_packages(params = {}, = {}) req = build_request(:describe_rules_packages, params) req.send_request() end |
#get_assessment_report(params = {}) ⇒ Types::GetAssessmentReportResponse
Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.
1519 1520 1521 1522 |
# File 'lib/aws-sdk-inspector/client.rb', line 1519 def get_assessment_report(params = {}, = {}) req = build_request(:get_assessment_report, params) req.send_request() end |
#get_exclusions_preview(params = {}) ⇒ Types::GetExclusionsPreviewResponse
Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token. You can obtain the preview token by running the CreateExclusionsPreview API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1588 1589 1590 1591 |
# File 'lib/aws-sdk-inspector/client.rb', line 1588 def get_exclusions_preview(params = {}, = {}) req = build_request(:get_exclusions_preview, params) req.send_request() end |
#get_telemetry_metadata(params = {}) ⇒ Types::GetTelemetryMetadataResponse
Information about the data that is collected for the specified assessment run.
1781 1782 1783 1784 |
# File 'lib/aws-sdk-inspector/client.rb', line 1781 def (params = {}, = {}) req = build_request(:get_telemetry_metadata, params) req.send_request() end |
#list_assessment_run_agents(params = {}) ⇒ Types::ListAssessmentRunAgentsResponse
Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2021 2022 2023 2024 |
# File 'lib/aws-sdk-inspector/client.rb', line 2021 def list_assessment_run_agents(params = {}, = {}) req = build_request(:list_assessment_run_agents, params) req.send_request() end |
#list_assessment_runs(params = {}) ⇒ Types::ListAssessmentRunsResponse
Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2121 2122 2123 2124 |
# File 'lib/aws-sdk-inspector/client.rb', line 2121 def list_assessment_runs(params = {}, = {}) req = build_request(:list_assessment_runs, params) req.send_request() end |
#list_assessment_targets(params = {}) ⇒ Types::ListAssessmentTargetsResponse
Lists the ARNs of the assessment targets within this AWS account. For more information about assessment targets, see [Amazon Inspector Assessment Targets].
[1]: docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2198 2199 2200 2201 |
# File 'lib/aws-sdk-inspector/client.rb', line 2198 def list_assessment_targets(params = {}, = {}) req = build_request(:list_assessment_targets, params) req.send_request() end |
#list_assessment_templates(params = {}) ⇒ Types::ListAssessmentTemplatesResponse
Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2285 2286 2287 2288 |
# File 'lib/aws-sdk-inspector/client.rb', line 2285 def list_assessment_templates(params = {}, = {}) req = build_request(:list_assessment_templates, params) req.send_request() end |
#list_event_subscriptions(params = {}) ⇒ Types::ListEventSubscriptionsResponse
Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template. For more information, see SubscribeToEvent and UnsubscribeFromEvent.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2366 2367 2368 2369 |
# File 'lib/aws-sdk-inspector/client.rb', line 2366 def list_event_subscriptions(params = {}, = {}) req = build_request(:list_event_subscriptions, params) req.send_request() end |
#list_exclusions(params = {}) ⇒ Types::ListExclusionsResponse
List exclusions that are generated by the assessment run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2414 2415 2416 2417 |
# File 'lib/aws-sdk-inspector/client.rb', line 2414 def list_exclusions(params = {}, = {}) req = build_request(:list_exclusions, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2515 2516 2517 2518 |
# File 'lib/aws-sdk-inspector/client.rb', line 2515 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_rules_packages(params = {}) ⇒ Types::ListRulesPackagesResponse
Lists all available Amazon Inspector rules packages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2578 2579 2580 2581 |
# File 'lib/aws-sdk-inspector/client.rb', line 2578 def list_rules_packages(params = {}, = {}) req = build_request(:list_rules_packages, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with an assessment template.
2628 2629 2630 2631 |
# File 'lib/aws-sdk-inspector/client.rb', line 2628 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#preview_agents(params = {}) ⇒ Types::PreviewAgentsResponse
Previews the agents installed on the EC2 instances that are part of the specified assessment target.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2703 2704 2705 2706 |
# File 'lib/aws-sdk-inspector/client.rb', line 2703 def preview_agents(params = {}, = {}) req = build_request(:preview_agents, params) req.send_request() end |
#register_cross_account_access_role(params = {}) ⇒ Struct
Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments.
2737 2738 2739 2740 |
# File 'lib/aws-sdk-inspector/client.rb', line 2737 def register_cross_account_access_role(params = {}, = {}) req = build_request(:register_cross_account_access_role, params) req.send_request() end |
#remove_attributes_from_findings(params = {}) ⇒ Types::RemoveAttributesFromFindingsResponse
Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.
2796 2797 2798 2799 |
# File 'lib/aws-sdk-inspector/client.rb', line 2796 def remove_attributes_from_findings(params = {}, = {}) req = build_request(:remove_attributes_from_findings, params) req.send_request() end |
#set_tags_for_resource(params = {}) ⇒ Struct
Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.
2844 2845 2846 2847 |
# File 'lib/aws-sdk-inspector/client.rb', line 2844 def (params = {}, = {}) req = build_request(:set_tags_for_resource, params) req.send_request() end |
#start_assessment_run(params = {}) ⇒ Types::StartAssessmentRunResponse
Starts the assessment run specified by the ARN of the assessment template. For this API to function properly, you must not exceed the limit of running up to 500 concurrent agents per AWS account.
2897 2898 2899 2900 |
# File 'lib/aws-sdk-inspector/client.rb', line 2897 def start_assessment_run(params = {}, = {}) req = build_request(:start_assessment_run, params) req.send_request() end |
#stop_assessment_run(params = {}) ⇒ Struct
Stops the assessment run that is specified by the ARN of the assessment run.
2937 2938 2939 2940 |
# File 'lib/aws-sdk-inspector/client.rb', line 2937 def stop_assessment_run(params = {}, = {}) req = build_request(:stop_assessment_run, params) req.send_request() end |
#subscribe_to_event(params = {}) ⇒ Struct
Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
2981 2982 2983 2984 |
# File 'lib/aws-sdk-inspector/client.rb', line 2981 def subscribe_to_event(params = {}, = {}) req = build_request(:subscribe_to_event, params) req.send_request() end |
#unsubscribe_from_event(params = {}) ⇒ Struct
Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.
3025 3026 3027 3028 |
# File 'lib/aws-sdk-inspector/client.rb', line 3025 def unsubscribe_from_event(params = {}, = {}) req = build_request(:unsubscribe_from_event, params) req.send_request() end |
#update_assessment_target(params = {}) ⇒ Struct
Updates the assessment target that is specified by the ARN of the assessment target.
If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target.
3071 3072 3073 3074 |
# File 'lib/aws-sdk-inspector/client.rb', line 3071 def update_assessment_target(params = {}, = {}) req = build_request(:update_assessment_target, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3095 3096 3097 |
# File 'lib/aws-sdk-inspector/client.rb', line 3095 def waiter_names [] end |